pub struct SquadMessageFlags(/* private fields */);Expand description
Squad message flags.
Implementations
Sourceimpl SquadMessageFlags
impl SquadMessageFlags
Sourcepub const IS_BROADCAST: SquadMessageFlags
pub const IS_BROADCAST: SquadMessageFlags
Message is a broadcast.
Sourceimpl SquadMessageFlags
impl SquadMessageFlags
Sourcepub const fn empty() -> SquadMessageFlags
pub const fn empty() -> SquadMessageFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> SquadMessageFlags
pub const fn all() -> SquadMessageFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<SquadMessageFlags>
pub const fn from_bits(bits: u8) -> Option<SquadMessageFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> SquadMessageFlags
pub const fn from_bits_truncate(bits: u8) -> SquadMessageFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> SquadMessageFlags
pub const fn from_bits_retain(bits: u8) -> SquadMessageFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SquadMessageFlags>
pub fn from_name(name: &str) -> Option<SquadMessageFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SquadMessageFlags) -> bool
pub const fn intersects(&self, other: SquadMessageFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SquadMessageFlags) -> bool
pub const fn contains(&self, other: SquadMessageFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SquadMessageFlags)
pub fn insert(&mut self, other: SquadMessageFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SquadMessageFlags)
pub fn remove(&mut self, other: SquadMessageFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SquadMessageFlags)
pub fn toggle(&mut self, other: SquadMessageFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SquadMessageFlags, value: bool)
pub fn set(&mut self, other: SquadMessageFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SquadMessageFlags) -> SquadMessageFlags
pub const fn intersection(self, other: SquadMessageFlags) -> SquadMessageFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SquadMessageFlags) -> SquadMessageFlags
pub const fn union(self, other: SquadMessageFlags) -> SquadMessageFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SquadMessageFlags) -> SquadMessageFlags
pub const fn difference(self, other: SquadMessageFlags) -> SquadMessageFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: SquadMessageFlags,
) -> SquadMessageFlags
pub const fn symmetric_difference( self, other: SquadMessageFlags, ) -> SquadMessageFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SquadMessageFlags
pub const fn complement(self) -> SquadMessageFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SquadMessageFlags
impl SquadMessageFlags
Sourcepub const fn iter(&self) -> Iter<SquadMessageFlags>
pub const fn iter(&self) -> Iter<SquadMessageFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SquadMessageFlags>
pub const fn iter_names(&self) -> IterNames<SquadMessageFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.